// Feather9x_TX
// -*- mode: C++ -*-
// Example sketch showing how to create a simple messaging client (transmitter)
// with the RH_RF95 class. RH_RF95 class does not provide for addressing or
// reliability, so you should only use RH_RF95 if you do not need the higher
// level messaging abilities.
// It is designed to work with the other example Feather9x_RX

// Board: Adafruit Feather M0 with RFM95 LoRa Radio 

#include <SPI.h>
#include <RH_RF95.h>

// for feather m0 with integrated LoRa module - feather m0 RFM9x
#define RFM95_CS 8
#define RFM95_RST 4
#define RFM95_INT 3

const float RF95_FREQ = 868.0;           // Frequency for RFM95W
const int RF95_TX_POWER = 23;            // 5..23 dBm, 13 dBm is default

// Singleton instance of the radio driver
RH_RF95 rf95(RFM95_CS, RFM95_INT);

/*************************** Variables ***********************************/

String newLine = "";

void setup()
{
  pinMode(RFM95_RST, OUTPUT);
  digitalWrite(RFM95_RST, HIGH);

  Serial.begin(115200);
  Serial1.begin(9600); //serial get DATA from main board

  delay(100);

  //Serial.println("Feather LoRa TX Test!");

  //Manual reset
  
  digitalWrite(RFM95_RST, LOW);
  delay(10);
  digitalWrite(RFM95_RST, HIGH);
  delay(10);

  while (!rf95.init()) 
  {
    //Serial.println("LoRa radio init failed");
    while (1);
  }
  
  //Serial.println("LoRa radio init OK!");

  //Defaults after init are 434.0MHz, modulation GFSK_Rb250Fd250, +13dbM
  if (!rf95.setFrequency(RF95_FREQ)) {
    //Serial.println("setFrequency failed");
    while (1);
  }
  
  //Serial.print("Set Freq to: "); Serial.println(RF95_FREQ);
  //Defaults after init are 434.0MHz, 13dBm, Bw = 125 kHz, Cr = 4/5, Sf = 128chips/symbol, CRC on

  // The default transmitter power is 13dBm, using PA_BOOST.
  // If you are using RFM95/96/97/98 modules which uses the PA_BOOST transmitter pin, then
  // you can set transmitter powers from 5 to 23 dBm:
  rf95.setTxPower(RF95_TX_POWER, false);
}


void loop()
{
  TakeLine(); //Get data from main board
  Serial.println(newLine);

  int str_len = newLine.length() + 1; 
  char char_array[str_len];

  newLine.toCharArray(char_array, str_len);
  rf95.send((uint8_t *)char_array, str_len); //Send data
  rf95.waitPacketSent();
  
  delay(1000); //Decrease to send faster
}

void TakeLine() //Serial comunication between Microcontrolers
{
  newLine="";
  Serial1.write("l");

   while (Serial1.available()) {
    delay(1);  //small delay to allow input buffer to fill
    char c = Serial1.read();  //gets one byte from serial buffer
    if (c == 'f') {
      break; //breaks out of capture loop to print readstring
    }  
    newLine += c; //makes the string readString
  }
}
